From: safemode <safemode@speakeasy.net>
To: Ignacio Vazquez-Abrams <ignacio@openservices.net>,
<linux-kernel@vger.kernel.org>
Subject: Re: [PATCH] Athlon bug stomper. Pls apply.
Date: Wed, 19 Sep 2001 17:43:30 -0400 [thread overview]
Message-ID: <20010919214317Z274216-760+14235@vger.kernel.org> (raw)
In-Reply-To: <Pine.LNX.4.33.0109191635310.29593-100000@terbidium.openservices.net>
In-Reply-To: <Pine.LNX.4.33.0109191635310.29593-100000@terbidium.openservices.net>
On Wednesday 19 September 2001 16:40, Ignacio Vazquez-Abrams wrote:
> On Wed, 19 Sep 2001, Ignacio Vazquez-Abrams wrote:
> > On Wed, 19 Sep 2001, Ignacio Vazquez-Abrams wrote:
> > > From an Athlon 1050/KT133 (middle 3 of 5):
> > >
> > > Clear:
> > > warm up run: 16653.33
> > > 2.4 non MMX: 10803.33
> > > 2.4 MMX fallback: 10576.67
> > > 2.4 MMX version: 9824.33
> > > faster_copy: 4416.67
> > > even_faster: 4316.67
> > >
> > > Copy:
> > > warm up run: 15268.33
> > > 2.4 non MMX: 23765.33
> > > 2.4 MMX fallback: 23629.33
> > > 2.4 MMX version: 15316.67
> > > faster_copy: 9352.00
> > > even_faster: 9333.33
> >
> > Please note that the 'faster_copy' under clear is in fact
> > 'faster_clear_page'. It got messed up in the post-processing of the
> > results.
>
> After Athlon patch:
>
> clear_page() tests
> clear_page function 'warm up run' took 17860 cycles per page
> clear_page function '2.4 non MMX' took 11805 cycles per page
> clear_page function '2.4 MMX fallback' took 11777 cycles per page
> clear_page function '2.4 MMX version' took 12003 cycles per page
> clear_page function 'faster_clear_page' took 4416 cycles per page
> clear_page function 'even_faster_clear' took 4315 cycles per page
>
> copy_page() tests
> copy_page function 'warm up run' took 14930 cycles per page
> copy_page function '2.4 non MMX' took 23337 cycles per page
> copy_page function '2.4 MMX fallback' took 23314 cycles per page
> copy_page function '2.4 MMX version' took 20293 cycles per page
> copy_page function 'faster_copy' took 9159 cycles per page
> copy_page function 'even_faster' took 9071 cycles per page
>
> This is with 2.4.9-ac12-preempt1 in both cases and niced to -20. Subsequent
> runs are very similar.
this is with 2.4.9-ac12 non preempt and without the patch on an athlon 850
k7-2 . niced to -20. It was compiled with gcc 3.0.2 no CFLAGS
Athlon test program $Id: fast.c,v 1.6 2000/09/23 09:05:45 arjan Exp $
clear_page() tests
clear_page function 'warm up run' took 21392 cycles per page
clear_page function '2.4 non MMX' took 14020 cycles per page
clear_page function '2.4 MMX fallback' took 14778 cycles per page
clear_page function '2.4 MMX version' took 15416 cycles per page
clear_page function 'faster_clear_page' took 4396 cycles per page
clear_page function 'even_faster_clear' took 4165 cycles per page
copy_page() tests
copy_page function 'warm up run' took 19788 cycles per page
copy_page function '2.4 non MMX' took 23562 cycles per page
copy_page function '2.4 MMX fallback' took 23174 cycles per page
copy_page function '2.4 MMX version' took 20422 cycles per page
copy_page function 'faster_copy' took 10132 cycles per page
copy_page function 'even_faster' took 9449 cycles per page
Using optimizations with this code actually slows it down for me. perhaps
this means something. When using asm code, perhaps it's better to not use
any compiler flags in the kernel config. The patch is still needed of course
to stop user programs from crashing the system, but maybe in the kernel for
asm sources you shouldn't try any compiler flags and see if that increases
performance. this could all be a gcc 3.x'ism though.
next prev parent reply other threads:[~2001-09-19 21:43 UTC|newest]
Thread overview: 69+ messages / expand[flat|nested] mbox.gz Atom feed top
2001-09-18 14:51 VDA
2001-09-18 15:43 ` Alan Cox
2001-09-20 4:56 ` Albert D. Cahalan
2001-09-18 17:45 ` Jeff Garzik
2001-09-18 21:39 ` Liakakis Kostas
2001-09-19 13:08 ` Re[2]: " VDA
2001-09-19 13:41 ` Liakakis Kostas
2001-09-19 13:47 ` Thomas Langås
2001-09-19 14:31 ` Liakakis Kostas
2001-09-19 14:43 ` Stefan Smietanowski
2001-09-19 14:55 ` Re[2]: " Jan Niehusmann
2001-09-19 14:57 ` Liakakis Kostas
2001-09-19 18:12 ` Alan Cox
2001-09-19 21:18 ` Re[2]: [PATCH] VIA " Aaron Tiensivu
2001-09-19 23:04 ` Roberto Jung Drebes
2001-09-19 23:41 ` Nicholas Knight
2001-09-19 16:00 ` Re[2]: [PATCH] Athlon " Linus Torvalds
2001-09-19 17:15 ` safemode
2001-09-19 18:22 ` Stefan Smietanowski
2001-09-19 23:41 ` Re[2]: " Nicholas Knight
2001-09-20 15:10 ` Marek Mentel
2001-09-19 18:43 ` Dan Hollis
2001-09-19 18:55 ` Arjan van de Ven
2001-09-19 19:00 ` Roberto Jung Drebes
2001-09-19 19:17 ` Arjan van de Ven
2001-09-19 20:16 ` Dan Hollis
2001-09-19 19:50 ` Ignacio Vazquez-Abrams
2001-09-19 20:01 ` Ignacio Vazquez-Abrams
2001-09-19 20:40 ` Ignacio Vazquez-Abrams
2001-09-19 21:43 ` safemode [this message]
2001-09-19 22:22 ` Brad Pepers
2001-09-19 22:28 ` Erno Kuusela
2001-09-19 20:36 ` Vojtech Pavlik
2001-09-19 20:57 ` Dan Hollis
2001-09-19 21:29 ` Vojtech Pavlik
2001-09-19 23:23 ` Luigi Genoni
2001-09-19 18:58 ` Re[2]: " Roberto Jung Drebes
2001-09-19 20:35 ` Athlon bug stomper: perf. results brian
2001-09-19 20:30 ` Dan Hollis
2001-09-19 22:14 ` brian
2001-09-19 22:08 ` Dan Hollis
2001-09-19 20:36 ` [PATCH] Athlon bug stomper. Pls apply Simen Thoresen
2001-09-19 20:37 ` Dan Hollis
2001-09-19 20:51 ` Simen Thoresen
2001-09-19 23:00 ` Roberto Jung Drebes
2001-09-20 9:03 ` VDA
2001-09-21 0:46 ` Re[2]: " Pavel Machek
2001-09-20 0:19 ` Nicholas Knight
2001-09-20 1:27 ` Stefan Smietanowski
2001-09-20 9:54 ` Re[2]: " Liakakis Kostas
2001-09-19 23:04 ` Luigi Genoni
2001-09-19 14:05 ` Tom Diehl
2001-09-23 23:33 ` Jan Niehusmann
2001-09-24 15:44 ` bill davidsen
2001-09-19 21:15 Petr Vandrovec
2001-09-19 19:21 ` Arjan van de Ven
2001-09-19 19:51 ` Dan Hollis
2001-09-19 19:59 ` Arjan van de Ven
2001-09-19 21:44 ` Eric W. Biederman
2001-09-19 22:13 ` Dan Hollis
2001-09-19 22:49 ` John Alvord
2001-09-19 23:14 ` Dan Hollis
2001-09-19 23:32 ` Daniel T. Chen
2001-09-19 22:55 ` Roberto Jung Drebes
2001-09-21 17:22 ` bill davidsen
2001-09-21 19:13 ` Dan Hollis
2001-09-19 20:52 ` Vojtech Pavlik
2001-09-19 23:33 Leif Sawyer
2001-09-20 13:08 Petr Vandrovec
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20010919214317Z274216-760+14235@vger.kernel.org \
--to=safemode@speakeasy.net \
--cc=ignacio@openservices.net \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®